import java.io.ByteArrayInputStream;
import java.sql.*;

class DatabaseTest
{
  private static Connection connection;
  
  public static void openConnection() {
    if (connection == null) {
      try {
        Class.forName("com.mysql.jdbc.Driver");
        connection = DriverManager.getConnection("jdbc:mysql://localhost:3306/Test?autoReconnect=true", "root", "");
      }
      catch (Exception e) {
        System.err.println("openConnection(): " + e);
        connection = null;
      }
    }
  }

  public static void closeConnection() {
    if (connection != null) {
      try {
	connection.close();
      }
      catch (Exception e) {
	System.err.println(e);
      }
      connection = null;
    }
  }
  
  public static void showServerVariables() {
    try {
      Statement stmt = connection.createStatement();
      String query = "SHOW VARIABLES";
      ResultSet result = stmt.executeQuery(query);
      
      while (result.next()) {
        System.out.println(result.getString(1) + " = " + result.getString(2));
      }
      stmt.close();
    }
    catch (Exception e) {
      System.err.println("showServerVariables(): " + e);
    }
  }

  public static void clearRecords() {
    try {
      Statement stmt = connection.createStatement();
      String update = "DELETE FROM Table1";

      stmt.executeUpdate(update);
      stmt.close();
    }
    catch (Exception e) {
      System.err.println("clearRecords(): " + e);
    }
  }

  public static void addRecord(String name, int size) {
    try {
      String update = "INSERT INTO Table1 (Name, Data) VALUES (?, ?)"; 
      PreparedStatement stmt = connection.prepareStatement(update);

      int index = 1;
      stmt.setString(index++, name);
      byte data[] = new byte[size];
      stmt.setBytes(index++, data);

      stmt.executeUpdate();
      stmt.close();
    
      System.out.println("addRecord() successful: name = " + name + ", size = " + size);
    }
    catch (Exception e) {
      System.err.println("addRecord() failed: name = " + name + ", size = " + size + ": " + e);
    }
  }

  public static void addRecord(String name) {
    try {
      String update = "INSERT INTO Table1 (Name) VALUES (?)"; 
      PreparedStatement stmt = connection.prepareStatement(update);

      int index = 1;
      stmt.setString(index++, name);

      stmt.executeUpdate();
      stmt.close();
    
      System.out.println("addRecord() successful: name = " + name);
    }
    catch (Exception e) {
      System.err.println("addRecord() failed: name = " + name + ": " + e);
    }
  }

  public static void setData(String name, int size) {
    try {
      String update = "UPDATE Table1 SET Data = ? WHERE Name = '" + name  + "'";
      PreparedStatement stmt = connection.prepareStatement(update);

      int index = 1;
      byte data[] = new byte[size];

      // Either of these statements yield the same result.
      stmt.setBytes(index++, data);
      //stmt.setBinaryStream(index++, new ByteArrayInputStream(data), data.length);

      stmt.executeUpdate();
      stmt.close();
    
      System.out.println("setData() successful: name = " + name + ", size = " + size);
    }
    catch (Exception e) {
      System.err.println("setData() failed: name = " + name + ", size = " + size + ": " + e);
    }
  }

  public static void main(String args[]) {
    int startSize = 0;
    int endSize   = 0;

    try {
      startSize = Integer.parseInt(args[0]);
      endSize   = Integer.parseInt(args[1]);
    }
    catch (Exception e) {
      System.out.println("Usage: DatabaseTest <Start Size> <End Size>");
      System.exit(-1);
    }

    DatabaseTest.openConnection();
    DatabaseTest.showServerVariables();
    DatabaseTest.clearRecords();
    for (int i = startSize; i <= endSize; i++) {
      String name = "Name" + i;
      int size = 1000000 * i;
      //DatabaseTest.addRecord("NameAndData" + name, size);
      DatabaseTest.addRecord("NameOnly" + name);
      DatabaseTest.setData("NameOnly" + name, size);
    }
    DatabaseTest.closeConnection();
  }
}
